@@ -3,6 +3,10 @@
 //! Its aims at converting [Wiremock stubs](http://wiremock.org/docs/stubbing/) into
 //! [wiremock-rs](https://github.com/LukeMathWalker/wiremock-rs) mocks.
 //!
+//! You can also use [stubr-build](https://crates.io/crates/stubr-build) to share stubs between a producer project and a consumer one.
+//!
+//! Also available as a [cli](https://crates.io/crates/stubr-cli).
+//!
 //! # use it
 //!
 //! ```no_run
@@ -84,6 +88,8 @@ pub use record::client::isahc_client;
 pub use record::client::reqwest_client;
 pub use server::{config::Config, Stubr};
 #[cfg(feature = "attributes")]
+pub use stubr_attributes::apps;
+#[cfg(feature = "attributes")]
 pub use stubr_attributes::mock;
 #[cfg(all(feature = "record", feature = "attributes"))]
 pub use stubr_attributes::record;
