@@ -10,9 +10,10 @@ use helpers::{
     datetime::NowHelper,
     json_path::JsonPathHelper,
     numbers::NumberHelper,
+    string::StringHelper,
     trim::TrimHelper,
     url_encode::UrlEncodingHelper,
-    string::StringHelper,
+    size::SizeHelper,
 };
 
 use crate::{cloud::opentracing::OpenTracing, model::response::ResponseStub};
@@ -37,6 +38,7 @@ lazy_static! {
         handlebars.register_helper(StringHelper::DECAPITALIZE, Box::new(StringHelper));
         handlebars.register_helper(StringHelper::UPPER, Box::new(StringHelper));
         handlebars.register_helper(StringHelper::LOWER, Box::new(StringHelper));
+        handlebars.register_helper(SizeHelper::NAME, Box::new(SizeHelper));
         RwLock::new(handlebars)
     };
 }
@@ -55,8 +57,8 @@ impl Respond for StubTemplate {
             let data = HandlebarsData::from(req);
             resp = self.response.body.render_response_template(resp, &data);
             resp = self.response.headers.render_response_template(resp, &data);
-            resp
-        } else { resp }
+        }
+        resp
     }
 }
 
