@@ -2,6 +2,7 @@ use std::{convert::TryFrom, net::TcpListener};
 
 use async_std::{path::PathBuf, task::block_on};
 use async_std::stream::Stream;
+use futures::future::join_all;
 use futures::stream::StreamExt;
 use log::info;
 use wiremock::{Mock, MockServer};
@@ -14,7 +15,7 @@ use crate::{cloud::probe::HttpProbe, Config};
 use crate::record::{config::RecordConfig, StubrRecord};
 
 mod stub;
-mod stub_finder;
+pub mod stub_finder;
 pub mod config;
 
 /// Allows running a Wiremock mock server from Wiremock stubs.
@@ -43,7 +44,7 @@ impl Stubr {
     /// Use this in a test context.
     /// * `stubs` - folder or file containing the stubs
     pub fn start_blocking<T>(stubs: T) -> Self where T: Into<PathBuf> {
-        block_on(Self::start(stubs))
+        Self::start_blocking_with(stubs, Config::default())
     }
 
     /// Runs a mock server with some configuration.
@@ -83,6 +84,46 @@ impl Stubr {
         StubrRecord::record(config)
     }
 
+    /// Runs stubs of a remote producer app.
+    /// * `name` - producer name
+    pub async fn app(name: &str) -> Self {
+        Self::app_with(name, Config::default()).await
+    }
+
+    /// Runs stubs of a remote producer app.
+    /// * `name` - producer name
+    pub async fn app_with(name: &str, config: Config) -> Self {
+        Self::start_with(StubFinder::find_app(name), config).await
+    }
+
+    /// Runs stubs of a remote producer app.
+    /// * `name` - producer name
+    pub fn app_blocking(name: &str) -> Self {
+        Self::app_blocking_with(name, Config::default())
+    }
+
+    /// Runs stubs of a remote producer app.
+    /// * `name` - producer name
+    pub fn app_blocking_with(name: &str, config: Config) -> Self {
+        block_on(Self::app_with(name, config))
+    }
+
+    pub async fn apps(names: &[&str]) -> Vec<Self> {
+        Self::apps_with(names, Config::default()).await
+    }
+
+    pub async fn apps_with(names: &[&str], config: Config) -> Vec<Self> {
+        join_all(names.iter().map(|n| async move { Self::app_with(n, config).await })).await
+    }
+
+    pub fn apps_blocking(names: &[&str]) -> Vec<Self> {
+        Self::apps_blocking_with(names, Config::default())
+    }
+
+    pub fn apps_blocking_with(names: &[&str], config: Config) -> Vec<Self> {
+        block_on(Self::apps_with(names, config))
+    }
+
     /// Get running server address
     pub fn uri(&self) -> String {
         self.instance.uri()
